# Omoospace

Omoospace is a scalable directory structure solution for digital creation works. In order to follow omoospace rules easily, we provide CLI tools, including creating omoospace, shipping package, setting subspace, etc.

[What is "Omoospace", how does it rule all your creation files?](https://omoolab.github.io/omoospace/omoospace/)

## Installation
This tool requires python version 3.9 or above [(python official download link)](https://www.python.org/downloads/). You can use [pyenv](https://github.com/pyenv/pyenv) or [conda](https://conda.io/projects/conda/en/latest/user-guide/install/index.html) for managing multiple python versions on a single machine.

Run the following command to install omoospace:

```shell
pip install omoospace
```

Check if omoospace CLI tools is installed correctly.

```shell
omoos --help
```

## Usage

[How to use CLI tools to manage a omoospace](https://omoolab.github.io/omoospace/)